summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/tree.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit90363652674deb94cd07057428b24fcb1735dbce (patch)
tree35013223cb731f194f8584cc1c06a023c3c75c85 /noatun-plugins/oblique/tree.h
parent627b091fad9df13695f249588e8a58f524eda0fa (diff)
downloadtdeaddons-90363652674deb94cd07057428b24fcb1735dbce.tar.gz
tdeaddons-90363652674deb94cd07057428b24fcb1735dbce.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeaddons@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'noatun-plugins/oblique/tree.h')
-rw-r--r--noatun-plugins/oblique/tree.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/noatun-plugins/oblique/tree.h b/noatun-plugins/oblique/tree.h
index bdc557d..c8e545e 100644
--- a/noatun-plugins/oblique/tree.h
+++ b/noatun-plugins/oblique/tree.h
@@ -23,15 +23,15 @@ class TreeItem : public KListViewItem
bool mHidden:1;
public:
- TreeItem(Tree *tqparent, QueryGroup *group, const File &file, const TQString &p=0);
- TreeItem(TreeItem *tqparent, QueryGroup *group, const File &file, const TQString &p=0);
+ TreeItem(Tree *parent, QueryGroup *group, const File &file, const TQString &p=0);
+ TreeItem(TreeItem *parent, QueryGroup *group, const File &file, const TQString &p=0);
~TreeItem();
QueryGroup *group() { return mGroup; }
const QueryGroup *group() const { return mGroup; }
void setGroup(QueryGroup *group) { mGroup = group; }
- TreeItem *tqparent() { return static_cast<TreeItem*>(KListViewItem::tqparent()); }
+ TreeItem *parent() { return static_cast<TreeItem*>(KListViewItem::parent()); }
Tree *tree();
TreeItem *itemBelow() { return static_cast<TreeItem*>(KListViewItem::itemBelow()); }
TreeItem *firstChild() { return static_cast<TreeItem*>(KListViewItem::firstChild()); }
@@ -51,7 +51,7 @@ public:
/**
* get the next item that is playable logically.
* that is, if it has a File, and its tqparent hasn't a
* File
**/
TreeItem *nextPlayable();
@@ -104,7 +104,7 @@ Q_OBJECT
Loader *mLoader;
public:
- Tree(Oblique *oblique, TQWidget *tqparent=0);
+ Tree(Oblique *oblique, TQWidget *parent=0);
~Tree();
TreeItem *firstChild();
TreeItem *find(File item);
@@ -130,7 +130,7 @@ public:
protected:
virtual TQDragObject *dragObject();
- void movableDropEvent(TQListViewItem* tqparent, TQListViewItem* afterme);
+ void movableDropEvent(TQListViewItem* parent, TQListViewItem* afterme);
public slots:
void insert(TreeItem *replace, File file);
@@ -51,7 +51,7 @@ public:
/**
* get the next item that is playable logically.
- * that is, if it has a File, and its tqparent hasn't a
+ * that is, if it has a File, and its parent hasn't a
* File
**/